@@ -17,8 +17,6 @@
 
 Bass_pop_RKsolver <- function(Param, Temperature, G, Food, IC, times, N){
 
-  cat('ODE solution\n')
-
   # Integration extremes definition
   ti=times[1]           # Integration beginning
   tf=times[2]           # Integration end
@@ -35,6 +33,8 @@ Bass_pop_RKsolver <- function(Param, Temperature, G, Food, IC, times, N){
   ingvero=as.matrix(matrix(0,nrow=ti,ncol=1))         # Initialize actual ingestion vector
   tfun=as.matrix(matrix(0,nrow=ti,ncol=2))     # Initialize temperature limitations vector
   metab=as.matrix(matrix(0,nrow=ti,ncol=2))   # Initialize metabolic rates vector
+  O2=as.matrix(matrix(0,nrow=ti))       # Initialize oxygen consumption rates vector
+  NH4=as.matrix(matrix(0,nrow=ti))      # Initialize ammonia release rates vector
 
   for (t in ti:(tf-1)) {
 
@@ -82,6 +82,8 @@ Bass_pop_RKsolver <- function(Param, Temperature, G, Food, IC, times, N){
   ingestionvero=unlist(output[5])
   temperaturefun=output[[6]]
   metabolism=output[[7]]
+  oxygen=output[[8]]
+  ammonia=output[[9]]
 
   # Outputs creation
   wst=rbind(wst, waste)
@@ -90,10 +92,12 @@ Bass_pop_RKsolver <- function(Param, Temperature, G, Food, IC, times, N){
   ingvero=rbind(ingvero, ingestionvero)
   tfun=rbind(tfun, temperaturefun)
   metab=rbind(metab, metabolism)
+  O2=rbind(O2, oxygen)
+  NH4=rbind(NH4, ammonia)
 
 }  # Close cycle
 
-  output=list(weight,exc,wst,ing,ingvero,tfun,metab)
+  output=list(weight,exc,wst,ing,ingvero,tfun,metab, O2, NH4)
   return(output) # Bream_pop_RKsolver output
 
 } # Close function
