@@ -9,25 +9,9 @@
 #'
 #' @import matrixStats plotrix rstudioapi
 #'
-#' @import rgeos maptools rgdal maps ncdf4
-#'
-#' @importFrom utils txtProgressBar write.table read.table
-#' @importFrom raster stack brick setZ getZ writeRaster
-#' @importFrom sp coordinates proj4string gridded
-#'
-#'
 
 Bream_spatial_main<-function(userpath,forcings){
 
-# Load libraries
-#library(raster)
-#library(rgeos)
-#library(maptools)
-#library(rgdal)
-#library(maps)
-#library(sp)
-#library(ncdf4)
-
 cat('Bream bioenergetic individual model spatialized\n')
 cat(" \n")
 
@@ -175,8 +159,8 @@ days_commercial_map<-as.data.frame(cbind(t(coord),t(days_commercial)))
 sp::coordinates(weight_map) <- ~V1+V2
 sp::proj4string(weight_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(weight_map) = TRUE
-weight_brick <- brick(weight_map)
-weight_brick <- setZ(weight_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+weight_brick <- raster::brick(weight_map)
+weight_brick <- raster::setZ(weight_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(weight_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/weight.nc"), format="CDF", varname="weight", varunit= "g",
             longname="Weight of Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -187,8 +171,8 @@ raster::writeRaster(weight_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc
 sp::coordinates(potential_ingestion_map) <- ~V1+V2
 sp::proj4string(potential_ingestion_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(potential_ingestion_map) = TRUE
-potential_ingestion_brick <- brick(potential_ingestion_map)
-potential_ingestion_brick <- setZ(potential_ingestion_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+potential_ingestion_brick <- raster::brick(potential_ingestion_map)
+potential_ingestion_brick <- raster::setZ(potential_ingestion_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(potential_ingestion_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/potential_ingestion.nc"), format="CDF", varname="potential ingestion", varunit= "g/d",
             longname="Potential ingestion of Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -199,8 +183,8 @@ raster::writeRaster(potential_ingestion_brick, paste0(userpath,"/Bream_spatial/O
 sp::coordinates(actual_ingestion_map) <- ~V1+V2
 sp::proj4string(actual_ingestion_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(actual_ingestion_map) = TRUE
-actual_ingestion_brick <- brick(actual_ingestion_map)
-actual_ingestion_brick <- setZ(actual_ingestion_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+actual_ingestion_brick <- raster::brick(actual_ingestion_map)
+actual_ingestion_brick <- raster::setZ(actual_ingestion_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(actual_ingestion_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/actual_ingestion.nc"), format="CDF", varname="actual ingestion", varunit= "g/d",
             longname="actual ingestion of Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -211,8 +195,8 @@ raster::writeRaster(actual_ingestion_brick, paste0(userpath,"/Bream_spatial/Outp
 sp::coordinates(faeces_C_map) <- ~V1+V2
 sp::proj4string(faeces_C_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(faeces_C_map) = TRUE
-faeces_C_brick <- brick(faeces_C_map)
-faeces_C_brick <- setZ(faeces_C_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+faeces_C_brick <- raster::brick(faeces_C_map)
+faeces_C_brick <- raster::setZ(faeces_C_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(faeces_C_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/faeces_carbohydrates.nc"), format="CDF", varname="faeces carbohydrates", varunit= "g/d",
             longname="Carbohydrate in faeces produced by Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -223,8 +207,8 @@ raster::writeRaster(faeces_C_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_
 sp::coordinates(faeces_P_map) <- ~V1+V2
 sp::proj4string(faeces_P_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(faeces_P_map) = TRUE
-faeces_P_brick <- brick(faeces_P_map)
-faeces_P_brick <- setZ(faeces_P_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+faeces_P_brick <- raster::brick(faeces_P_map)
+faeces_P_brick <- raster::setZ(faeces_P_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(faeces_P_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/faeces_proteins.nc"), format="CDF", varname="faeces proteins", varunit= "g/d",
             longname="Proteins in faeces produced by Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -235,8 +219,8 @@ raster::writeRaster(faeces_P_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_
 sp::coordinates(faeces_L_map) <- ~V1+V2
 sp::proj4string(faeces_L_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(faeces_L_map) = TRUE
-faeces_L_brick <- brick(faeces_L_map)
-faeces_L_brick <- setZ(faeces_L_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+faeces_L_brick <- raster::brick(faeces_L_map)
+faeces_L_brick <- raster::setZ(faeces_L_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(faeces_L_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/faeces_lipids.nc"), format="CDF", varname="faeces lipids", varunit= "g/d",
             longname="Lipids in faeces produced by Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -247,8 +231,8 @@ raster::writeRaster(faeces_L_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_
 sp::coordinates(waste_C_map) <- ~V1+V2
 sp::proj4string(waste_C_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(waste_C_map) = TRUE
-waste_C_brick <- brick(waste_C_map)
-waste_C_brick <- setZ(waste_C_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+waste_C_brick <- raster::brick(waste_C_map)
+waste_C_brick <- raster::setZ(waste_C_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(waste_C_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/wasted_feed_carbohydrates.nc"), format="CDF", varname="wasted carbohydrates", varunit= "g/d",
             longname="Carbohydrates wasted feed by Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -259,8 +243,8 @@ raster::writeRaster(waste_C_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_n
 sp::coordinates(waste_L_map) <- ~V1+V2
 sp::proj4string(waste_L_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(waste_L_map) = TRUE
-waste_L_brick <- brick(waste_L_map)
-waste_L_brick <- setZ(waste_L_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+waste_L_brick <- raster::brick(waste_L_map)
+waste_L_brick <- raster::setZ(waste_L_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(waste_L_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/wasted_feed_lipids.nc"), format="CDF", varname="wasted lipids", varunit= "g/d",
             longname="Lipids wasted feed by Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -271,8 +255,8 @@ raster::writeRaster(waste_L_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_n
 sp::coordinates(waste_P_map) <- ~V1+V2
 sp::proj4string(waste_P_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(waste_P_map) = TRUE
-waste_P_brick <- brick(waste_P_map)
-waste_P_brick <- setZ(waste_P_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+waste_P_brick <- raster::brick(waste_P_map)
+waste_P_brick <- raster::setZ(waste_P_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(waste_P_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/wasted_feed_proteins.nc"), format="CDF", varname="wasted proteins", varunit= "g/d",
             longname="Proteins wasted by Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -283,8 +267,8 @@ raster::writeRaster(waste_P_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_n
 sp::coordinates(Tfun_A_map) <- ~V1+V2
 sp::proj4string(Tfun_A_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(Tfun_A_map) = TRUE
-Tfun_A_brick <- brick(Tfun_A_map)
-Tfun_A_brick <- setZ(Tfun_A_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+Tfun_A_brick <- raster::brick(Tfun_A_map)
+Tfun_A_brick <- raster::setZ(Tfun_A_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(Tfun_A_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/temperature_response_A.nc"), format="CDF", varname="Temperature response anabolism", varunit= "-",
             longname="temperature response function for anabolism of Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -293,10 +277,10 @@ raster::writeRaster(Tfun_A_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc
 
 # temperature response function for catabolism map
 sp::coordinates(Tfun_C_map) <- ~V1+V2
-sp::proj4string(Tfun_C_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
+sp::proj4string(Tfun_C_map)=CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(Tfun_C_map) = TRUE
-Tfun_C_brick <- brick(Tfun_C_map)
-Tfun_C_brick <- setZ(Tfun_C_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+Tfun_C_brick <- raster::brick(Tfun_C_map)
+Tfun_C_brick <- raster::setZ(Tfun_C_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(Tfun_C_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/temperature_response_C.nc"), format="CDF", varname="Temperature response catabolism", varunit= "-",
             longname="temperature response function for catabolism of Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -305,10 +289,10 @@ raster::writeRaster(Tfun_C_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc
 
 # anabolic rates map
 sp::coordinates(anabolism_map) <- ~V1+V2
-sp::proj4string(anabolism_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
+sp::proj4string(anabolism_map)=CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(anabolism_map) = TRUE
-anabolism_brick <- brick(anabolism_map)
-anabolism_brick <- setZ(anabolism_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+anabolism_brick <- raster::brick(anabolism_map)
+anabolism_brick <- raster::setZ(anabolism_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(anabolism_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/anabolic_rate.nc"), format="CDF", varname="Anabolic rate", varunit= "J/d",
             longname="anabolic rate for catabolism of Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -319,8 +303,8 @@ raster::writeRaster(anabolism_brick, paste0(userpath,"/Bream_spatial/Outputs/Out
 sp::coordinates(catabolism_map) <- ~V1+V2
 sp::proj4string(catabolism_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(catabolism_map) = TRUE
-catabolism_brick <- brick(catabolism_map)
-catabolism_brick <- setZ(catabolism_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+catabolism_brick <- raster::brick(catabolism_map)
+catabolism_brick <- raster::setZ(catabolism_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(catabolism_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/catabolic_rate.nc"), format="CDF", varname="Catabolic rate", varunit= "J/d",
             longname="catabolic rate for catabolism of Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -331,8 +315,8 @@ raster::writeRaster(catabolism_brick, paste0(userpath,"/Bream_spatial/Outputs/Ou
 sp::coordinates(NH4_map) <- ~V1+V2
 sp::proj4string(NH4_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(NH4_map) = TRUE
-NH4_brick <- brick(NH4_map)
-NH4_brick <- setZ(NH4_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+NH4_brick <- raster::brick(NH4_map)
+NH4_brick <- raster::setZ(NH4_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(NH4_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/NH4_release.nc"), format="CDF", varname="NH4 release", varunit= "gN",
             longname="Ammonia released by Sparus aurata estimated through the R RAC package developed by Baldan et al",
@@ -343,8 +327,8 @@ raster::writeRaster(NH4_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/NH
 sp::coordinates(O2_map) <- ~V1+V2
 sp::proj4string(O2_map)=sp::CRS(("+proj=longlat +datum=WGS84")) # set it to lat-long
 sp::gridded(O2_map) = TRUE
-O2_brick <- brick(O2_map)
-O2_brick <- setZ(O2_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
+O2_brick <- raster::brick(O2_map)
+O2_brick <- raster::setZ(O2_brick, as.Date(Dates[1])+ 0:(tf-ti))    ######ADD DATE
 
 raster::writeRaster(O2_brick, paste0(userpath,"/Bream_spatial/Outputs/Out_nc/O2_consumption.nc"), format="CDF", varname="O2 consumption", varunit= "g",
             longname="Oxygen consumed by Sparus aurata estimated through the R RAC package developed by Baldan et al",
